==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("thhruntmknkwgino")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("jqpgmxghbwrhjfha")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("rohlwdobhceipjan")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("pyfknwmcwiskqrvt")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("dbwmkuxpvlvohjdq")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("panjayifxqvjcnxb")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("cdjckntfqjlfdakk")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("ydrppagrgrlygrwm")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("jcdxxphsexkasktg")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("crmunorynxmyibnb")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("jvmymmcagnmvetwu")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("podhuwfqljjmusga")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("skxnopvtjepeqvjp")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("fkdaogribljsxpgk")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("smnvhwbccrdhqvmw")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("wltkmsiewbkbrxfw")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("mkojkkccugdfhbss")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("qpxpiumnujcyiywe")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("nrnvmcdkljufukwy")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("dxoaikcunfdpwpnc")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("ntvdhuoywheewpmf")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("thasbhbloejxeutm")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("nbeslchjkumlcvmp")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("udlgmgaheixrvvvo")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("yfmoxlanbqudmjpd")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("jfmhalhmmvcmoamy")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("fccrmgkhhtdtfjom")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("judwnhpmyjcrqbew")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("xsgbsogarertobsy")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("miodqgwurjacqarn")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("efkgmbocckphedhh")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("vslfukngsmtowuel")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("kqfrarwbjnwlawqg")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("oosjnlwtpqpsycwy")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("bflryxcdpsqpnhav")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("tnwtkihtxmdqhwag")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("xsvjnqoytrrksqsg")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("vgxrmjgltcfwaqju")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("jdlyiyfhjxowmoir")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("xpbftyjfpqkbqawi")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("gweafbwrmwpftics")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("slqybtxqrbvaofnf")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("gwqgsjcurbfgfxjl")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("ftuaapfclsnesuxn")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("ppinnlfdruursodm")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("hwoudyeqelgdadwn")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("qhckfmoxjaaysayt")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("rhyjhydyppnarrge")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("rmxugermsskrhild")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("ayjgkqoasmcnsgwj")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("scmaebhaxcddrktk")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("lgjriifxatmcfsel")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("vcfanbvunyetknxa")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("wfvgmjgwjfywsljw")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("kxmqnvofvplxpneq")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("syesnjupkwmylepq")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}
